from ._weather_query import weather_query as today_weather
from ._thesis_info import thesis_info as crawl_thesis_info
from ._ytb_channel_info import YTBInfoBot
from ._academic import PaperWithCodeQuery, ArxivQuery, IEEEQuery
from ._air_quality import AirQualityQuery

